==> texlive-base_2019.20200218.orig.tar.xz: texlive-base-2019.20200218/texmf-dist/doc/xelatex/xecjk/README.md <==
xeCJK
=====

`xeCJK` is a package written for XeLaTeX which allows users to typeset
CJK scripts easily.

 - Different default fonts for CJK and other characters.
 - Spaces automatically ignored between CJK characters.
 - Special effects on full-width CJK punctuation.
 - Automatic adjustment of the space between CJK and other characters.

Contributing
------------

This package is a part of the [ctex-kit](https://github.com/CTeX-org/ctex-kit) project.

Issues and pull requests are welcome.

Copyright and Licence
---------------------

    Copyright (C) 2007--2010 by Wenchang Sun <sunwch@nankai.edu.cn>
    Copyright (C) 2009--2020 by Leo Liu <leoliu.pku@gmail.com>
    Copyright (C) 2012--2020 by Qing Lee <sobenlee@gmail.com>
    ----------------------------------------------------------------------

    This work may be distributed and/or modified under the
    conditions of the LaTeX Project Public License, either
    version 1.3c of this license or (at your option) any later
    version. This version of this license is in
       http://www.latex-project.org/lppl/lppl-1-3c.txt
    and the latest version of this license is in
       http://www.latex-project.org/lppl.txt
    and version 1.3 or later is part of all distributions of
    LaTeX version 2005/12/01 or later.

    This work has the LPPL maintenance status `maintained'.

    The Current Maintainers of this work are Leo Liu and Qing Lee.

    This package consists of the files xeCJK.dtx,
                                       full-stop.map,
                                       fullwidth-stop.map,
                                       han-simp.map,
                                       han-trad.map,
                 and the derived files xeCJK.pdf,
                                       xeCJK.sty,
                                       xeCJK.cfg,
                                       xeCJK.ins,
                                       xeCJKfntef.sty,
                                       xeCJK-listings.sty,
                                       xunicode-addon.sty,
                                       xunicode-extra.def,
                                       xeCJK-example-autofake.tex,
                                       xeCJK-example-fallback.tex,
                                       xeCJK-example-subCJKblock.tex,
                                       xeCJK-example-CJKecglue.tex,
                                       xeCJK-example-checksingle.tex,
                                       xeCJK-example-CJKfntef.tex,
                                       xeCJK-example-punctstyle.tex,
                                       xeCJK-example-verbatim.tex,
                                       xeCJK-example-CM.tex,
                                       xeCJK-example-listings.tex,
                                       xeCJK-example-mathblock.tex,
                                       xunicode-symbols.tex,
                                       xunicode-commands.tex,
                                       xunicode-combine-marks.tex,
                                       xunicode-symbols.pdf,
                                       full-stop.tec,
                                       fullwidth-stop.tec,
                                       han-simp.tec,
                                       han-trad.tec, and
                                       README.md (this file).

==> texlive-base_2021.20220204.orig.tar.xz: texlive-base-2021.20220204/texmf-dist/doc/xelatex/xecjk/README.md <==
xeCJK
=====

`xeCJK` is a package written for XeLaTeX which allows users to typeset
CJK scripts easily.

 - Different default fonts for CJK and other characters.
 - Spaces automatically ignored between CJK characters.
 - Special effects on full-width CJK punctuation.
 - Automatic adjustment of the space between CJK and other characters.

Contributing
------------

This package is a part of the [ctex-kit](https://github.com/CTeX-org/ctex-kit) project.

Issues and pull requests are welcome.

Copyright and Licence
---------------------

    Copyright (C) 2007--2010 by Wenchang Sun <sunwch@nankai.edu.cn>
    Copyright (C) 2009--2021 by Leo Liu <leoliu.pku@gmail.com>
    Copyright (C) 2012--2021 by Qing Lee <sobenlee@gmail.com>
    ----------------------------------------------------------------------

    This work may be distributed and/or modified under the
    conditions of the LaTeX Project Public License, either
    version 1.3c of this license or (at your option) any later
    version. This version of this license is in
       http://www.latex-project.org/lppl/lppl-1-3c.txt
    and the latest version of this license is in
       http://www.latex-project.org/lppl.txt
    and version 1.3 or later is part of all distributions of
    LaTeX version 2005/12/01 or later.

    This work has the LPPL maintenance status "maintained".

    The Current Maintainers of this work are Leo Liu and Qing Lee.

    This package consists of the files xeCJK.dtx,
                                       full-stop.map,
                                       fullwidth-stop.map,
                                       han-simp.map,
                                       han-trad.map,
                 and the derived files xeCJK.pdf,
                                       xeCJK.sty,
                                       xeCJK.cfg,
                                       xeCJK.ins,
                                       xeCJKfntef.sty,
                                       xeCJK-listings.sty,
                                       xunicode-addon.sty,
                                       xunicode-extra.def,
                                       xeCJK-example-autofake.tex,
                                       xeCJK-example-fallback.tex,
                                       xeCJK-example-subCJKblock.tex,
                                       xeCJK-example-CJKecglue.tex,
                                       xeCJK-example-checksingle.tex,
                                       xeCJK-example-CJKfntef.tex,
                                       xeCJK-example-punctstyle.tex,
                                       xeCJK-example-verbatim.tex,
                                       xeCJK-example-CM.tex,
                                       xeCJK-example-listings.tex,
                                       xeCJK-example-mathblock.tex,
                                       xunicode-symbols.tex,
                                       xunicode-commands.tex,
                                       xunicode-combine-marks.tex,
                                       xunicode-symbols.pdf,
                                       full-stop.tec,
                                       fullwidth-stop.tec,
                                       han-simp.tec,
                                       han-trad.tec, and
                                       README.md (this file).
